@@ -17,10 +17,13 @@ import org.gcube.portlets.user.td.taskswidget.shared.job.TdOperationModel;
 
 import com.extjs.gxt.ui.client.Style.HorizontalAlignment;
 import com.extjs.gxt.ui.client.Style.Scroll;
+import com.extjs.gxt.ui.client.event.ButtonEvent;
+import com.extjs.gxt.ui.client.event.SelectionListener;
 import com.extjs.gxt.ui.client.widget.ContentPanel;
 import com.extjs.gxt.ui.client.widget.Dialog;
 import com.extjs.gxt.ui.client.widget.Html;
 import com.extjs.gxt.ui.client.widget.Label;
+import com.extjs.gxt.ui.client.widget.LayoutContainer;
 import com.extjs.gxt.ui.client.widget.MessageBox;
 import com.extjs.gxt.ui.client.widget.layout.FitLayout;
 import com.google.gwt.dom.client.Style.Cursor;
@@ -77,7 +80,7 @@ public class FlexTableJob extends FlexTable{
 		if(jobModel==null)
 			return;
 		
-//		System.out.println("Update Status for "+jobModel);
+		System.out.println("Update Status for "+jobModel);
 		Integer rowIndex = rowIndexJob.get(jobModel.getJobIdentifier());
 
 		if(rowIndex==null){
@@ -145,6 +148,66 @@ public class FlexTableJob extends FlexTable{
 					String operationId = type!=null? type.getOperationId():"";
 					setWidget(rowIndex, i, setDialogJobInfoDescription(operationId, jobModel));
 
+			}else if(columsConfigs.get(i).equals(ColumnConfigTdJobModel.ValidationJobs)){
+				
+				final List<TdJobModel> validationJob = jobModel.getListValidationJobModel();
+				
+				if(validationJob==null)
+					return;
+				
+				final Image validationImg = new Image(Resources.INSTANCE.validating());
+				
+				validationImg.addMouseOverHandler(new MouseOverHandler() {
+					
+					@Override
+					public void onMouseOver(MouseOverEvent event) {
+						validationImg.getElement().getStyle().setCursor(Cursor.POINTER); 
+						
+					}
+				});
+				
+				validationImg.addClickHandler(new ClickHandler() {
+					
+					@Override
+					public void onClick(ClickEvent arg0) {
+						final Dialog dialog = new Dialog();
+//						dialog.setLayout(new FitLayout());
+						dialog.setScrollMode(Scroll.AUTOY);
+						
+						dialog.setHeight(170);
+						
+//						dialog.setWidth(300);
+//						FlexTableJob flex = new FlexTableJob(TdJobModel.ColumnConfigTdJobModel.Progress, TdJobModel.ColumnConfigTdJobModel.StatusIcon);
+						
+						FlexTableJob flex = new FlexTableJob(TdJobModel.ColumnConfigTdJobModel.OperationInfo, TdJobModel.ColumnConfigTdJobModel.Progress, TdJobModel.ColumnConfigTdJobModel.StatusIcon);
+						dialog.setWidth(380);
+						
+						LayoutContainer lc = new LayoutContainer();
+						lc.mask("Loading");
+						for (TdJobModel tdJobModel : validationJob) {
+							flex.updateStatus(tdJobModel);
+							lc.unmask();
+						}
+						
+						dialog.getButtonById(Dialog.OK).addSelectionListener(new SelectionListener<ButtonEvent>() {
+
+							@Override
+							public void componentSelected(ButtonEvent ce) {
+								dialog.hide();
+							}
+
+						});
+						
+						dialog.setHeading("Validation Jobs");
+						lc.add(flex);
+						dialog.add(lc);
+						dialog.setHideOnButtonClick(true);
+						dialog.show();
+					}
+				});
+				
+				setWidget(rowIndex, i, validationImg);
+			
 			}else
 				setWidget(rowIndex, i, new Label(jobModel.get(columsConfigs.get(i).getId())+""));
 			
